<!-- Start Education -->
<h2>Education</h2>
<div>
    {% for experience in education %}
        <h4>{{ experience[0]["institution"] }}  | {{ experience[0]["title"] }}</h4>
        <!-- Metadata -->
        <h4>{{experience[0]["month_started"] | pretty_datetime(experience[0]["year_started"], experience[0]["month_ended"], experience[0]["year_ended"], experience[0]["current"])}}</h4>
        <!-- Content -->
        <p>{{ experience[1] | safe}}</p>
    {% endfor %}
</div>
<!-- End Education -->